@@ -2,13 +2,13 @@
    allocation.  For proper operation, the original precision need to be reset
    sooner or later.
 
-Copyright (C) 1996 Free Software Foundation, Inc.
+Copyright 1996, 2001 Free Software Foundation, Inc.
 
 This file is part of the GNU MP Library.
 
 The GNU MP Library is free software; you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at your
+the Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The GNU MP Library is distributed in the hope that it will be useful, but
@@ -17,23 +17,13 @@ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the GNU MP Library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-MA 02111-1307, USA. */
+along with the GNU MP Library.  If not, see http://www.gnu.org/licenses/.  */
 
 #include "gmp.h"
 #include "gmp-impl.h"
 
 void
-#if __STDC__
-mpf_set_prec_raw (mpf_ptr x, unsigned long int prec_in_bits)
-#else
-mpf_set_prec_raw (x, prec_in_bits)
-     mpf_ptr x;
-     unsigned long int prec_in_bits;
-#endif
+mpf_set_prec_raw (mpf_ptr x, mp_bitcnt_t prec_in_bits)
 {
-  mp_size_t prec;
-  prec = (MAX (53, prec_in_bits) + 2 * BITS_PER_MP_LIMB - 1)/BITS_PER_MP_LIMB;
-  x->_mp_prec = prec;
+  x->_mp_prec = __GMPF_BITS_TO_PREC (prec_in_bits);
 }
